@@ -9,7 +9,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -31,7 +31,7 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/gs.py rel_2.4.1:3453:73fefd3ea0b0 2015/11/09 03:25:05 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/gs.py 3a41ed6b288cee8d085373ad7fa02894e1903864 2019-01-23 17:30:35 bdeegan"
 
 import SCons.Action
 import SCons.Builder
@@ -62,12 +62,12 @@ def generate(env):
         if GhostscriptAction is None:
             GhostscriptAction = SCons.Action.Action('$GSCOM', '$GSCOMSTR')
     
-        import pdf
+        from SCons.Tool import pdf
         pdf.generate(env)
     
         bld = env['BUILDERS']['PDF']
         bld.add_action('.ps', GhostscriptAction)
-    except ImportError, e:
+    except ImportError as e:
         pass
 
     gsbuilder = SCons.Builder.Builder(action = SCons.Action.Action('$GSCOM', '$GSCOMSTR'))
