@@ -10,7 +10,7 @@ selection method.
 from __future__ import print_function
 
 #
-# Copyright (c) 2001 - 2017 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -32,9 +32,10 @@ from __future__ import print_function
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/swig.py rel_3.0.0:4395:8972f6a2f699 2017/09/18 12:59:24 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/swig.py 3a41ed6b288cee8d085373ad7fa02894e1903864 2019-01-23 17:30:35 bdeegan"
 
 import os.path
+import sys
 import re
 import subprocess
 
@@ -169,6 +170,17 @@ def generate(env):
     java_file.add_action('.i', SwigAction)
     java_file.add_emitter('.i', _swigEmitter)
 
+    from SCons.Platform.mingw import MINGW_DEFAULT_PATHS
+    from SCons.Platform.cygwin import CYGWIN_DEFAULT_PATHS
+
+    if sys.platform == 'win32':
+        swig = SCons.Tool.find_program_path(env, 'swig', default_paths=MINGW_DEFAULT_PATHS + CYGWIN_DEFAULT_PATHS + [r'C:\ProgramData\chocolatey\bin'] )
+        if swig:
+            swig_bin_dir = os.path.dirname(swig)
+            env.AppendENVPath('PATH', swig_bin_dir)
+        else:
+            SCons.Warnings.Warning('swig tool requested, but binary not found in ENV PATH')
+
     if 'SWIG' not in env:
         env['SWIG'] = env.Detect(swigs) or swigs[0]
     env['SWIGVERSION']       = _get_swig_version(env, env['SWIG'])
